@@ -1,6 +1,6 @@
 // This is the implementation of the Chimera class.
 //
-// Copyright (c) 2017 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2018 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
 // This file is part of PyQt5.
 // 
@@ -414,10 +414,6 @@ bool Chimera::parse_py_type(PyTypeObject *type_obj)
     {
         _metatype = QMetaType::QVariantList;
     }
-    else if (type_obj == &PyDict_Type)
-    {
-        _metatype = QMetaType::QVariantMap;
-    }
 #if PY_MAJOR_VERSION >= 3
     else if (type_obj == &PyUnicode_Type)
     {
